==> haskell-swagger2-2.8.9-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 swagger2
version:              2.8.9
visibility:           public
id:                   swagger2-2.8.9-4zkkbqwUiBFBoyTZmjKndP
key:                  swagger2-2.8.9-4zkkbqwUiBFBoyTZmjKndP
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  0bbf59697ac12e8cbc5373ab04fd8a92
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.9-4zkkbqwUiBFBoyTZmjKndP
depends:
    QuickCheck-2.14.3-DOFi1GQ9eE04hBoMxr6sJJ
    aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3
    aeson-pretty-0.8.10-5zcCOcYYUhIAAnbV0DgwbO base-4.17.2.1
    base-compat-batteries-0.12.2-GkmTCtsPQdM6qmnogRrRfk
    bytestring-0.11.5.3 containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    generics-sop-0.5.1.3-6y2YwPdVMIQ2rlUdjv5yXL
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig
    http-media-0.8.1.1-5ifpqULKjA0eFc0ednF9c
    insert-ordered-containers-0.2.5.3-Afk5M7TBmdFAIucHvFjdLl
    lens-5.2.3-I3BlAHfqsGAEvCz93DUGGV mtl-2.2.2
    network-3.1.4.0-HsnWpJCBJSkHDu8PyPRvYR
    optics-core-0.4.1.1-DQjgLprXn8iKZLA3bDM1t5
    optics-th-0.4.1-EBjqICIeMXhASEqp6vWAKf
    scientific-0.3.7.0-Jh9tJE2sLMpFL2bSsP8DMA template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g
    uuid-types-1.0.6-IQyEC4RLNlX9sNuZIMNyMl
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.8.9-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 swagger2
version:              2.8.9
visibility:           public
id:                   swagger2-2.8.9-Kh6vQ2kYNatHIac6Caya3q
key:                  swagger2-2.8.9-Kh6vQ2kYNatHIac6Caya3q
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  a04b86eb649e42ad201b11368cee1504
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/swagger2-2.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.9-Kh6vQ2kYNatHIac6Caya3q
depends:
    QuickCheck-2.14.3-DOFi1GQ9eE04hBoMxr6sJJ
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86
    aeson-pretty-0.8.10-LSMEybji2H0AjtTXnGZSdX base-4.17.2.1
    base-compat-batteries-0.12.2-GkmTCtsPQdM6qmnogRrRfk
    bytestring-0.11.5.3 containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    generics-sop-0.5.1.3-6y2YwPdVMIQ2rlUdjv5yXL
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig
    http-media-0.8.1.1-5ifpqULKjA0eFc0ednF9c
    insert-ordered-containers-0.2.5.3-2h4Kgz8ldoB5da8YtSLPZF
    lens-5.2.3-JlyZXwZS00NBv5ScwlVipn mtl-2.2.2
    network-3.1.4.0-HsnWpJCBJSkHDu8PyPRvYR
    optics-core-0.4.1.1-KNPzZ5dLIx4E34lxM9ZHmM
    optics-th-0.4.1-F9JcGPnoiIp3RfTc9lOMlB
    scientific-0.3.7.0-Jh9tJE2sLMpFL2bSsP8DMA template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g
    uuid-types-1.0.6-IQyEC4RLNlX9sNuZIMNyMl
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
